@@ -3,3 +3,5 @@
 
 from . import common
 from . import test_mailing_internals
+from . import test_mailing_retry
+from . import test_mailing_sms_ab_testing
